intelmq.bots.experts.modify package — intelmq 3.1.0.alpha1 documentation

# intelmq.bots.experts.modify package

## Submodules

## intelmq.bots.experts.modify.expert module

Modify Expert bot let’s you manipulate all fields with a config file.

intelmq.bots.experts.modify.expert.BOT

  alias of `intelmq.bots.experts.modify.expert.ModifyExpertBot`

class intelmq.bots.experts.modify.expert.MatchGroupMapping(match)

  Bases: `object`

  Wrapper for a regexp match object with a dict-like interface. With this, we can access the match groups from within a format replacement field.

class intelmq.bots.experts.modify.expert.ModifyExpertBot(bot_id: str, start: bool = False, sighup_event=None, disable_multithreading: Optional[bool] = None)

  Bases: `intelmq.lib.bot.ExpertBot`

  Perform arbitrary changes to event’s fields based on regular-expression-based rules on different values. See the bot’s documentation for some examples

  apply_action(event, action, matches)
  case_sensitive: bool = True
  configuration_path: str = '/opt/intelmq/var/lib/bots/modify/modify.conf'
  init()
  matches(identifier, event, condition)
  maximum_matches = None
  overwrite: bool = True
  process()

intelmq.bots.experts.modify.expert.is_re_pattern(value)

  Checks if the given value is a re compiled pattern

## Module contents